﻿using Infragistics.Windows;
using Infragistics.Windows.Ribbon;
using Infragistics.Windows.Ribbon.Internal;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace CAS_179006
{
    public partial class MenuItemEx : MenuItem, IKeyTipContainer
    {
        void IKeyTipContainer.Deactivate()
        {
            this.IsSubmenuOpen = false;
        }

        bool IKeyTipContainer.ReuseParentKeyTips
        {
            get { return false; }
        }

        public IKeyTip[] GetKeyTips()
        {
            return this.GetChildKeyTipProviders();
        }

        internal IKeyTip[] GetChildKeyTipProviders()
        {
            List<IKeyTip> providers = new List<IKeyTip>();
            ItemContainerGenerator generator = this.ItemContainerGenerator;

            if (null != generator)
            {
                foreach (object item in this.Items)
                {
                    MenuItemEx menuItem = item as MenuItemEx;

                    if (null == menuItem)
                        menuItem = generator.ContainerFromItem(item) as MenuItemEx;

                    if (null != menuItem)
                        providers.AddRange(menuItem.GetKeyTipProviders());
                }
            }

            return providers.ToArray();
        }

        internal IKeyTip[] GetKeyTipProviders()
        {
            return new IKeyTip[1] { new MenuItemExKeyTipProvider(this) };
        }
    }



    public class MenuItemExKeyTipProvider : IKeyTip
    {
        private MenuItemEx _menuItem;

        internal MenuItemExKeyTipProvider(MenuItemEx menuItem)
        {
            this._menuItem = menuItem;
        }

        bool IKeyTip.Activate()
        {
            if (_menuItem.HasItems)
            {
                _menuItem.IsSubmenuOpen = true;
            }
            else
            {
                _menuItem.RaiseEvent(new RoutedEventArgs(MenuItem.ClickEvent));
            }
            
            return true;
        }

        bool IKeyTip.Equals(IKeyTip provider)
        {
            return this == provider;
        }

        IKeyTipContainer IKeyTip.GetContainer()
        {
            switch (this._menuItem.Role)
            {
                default:
                case MenuItemRole.TopLevelItem:
                case MenuItemRole.SubmenuItem:
                    return null;
                case MenuItemRole.SubmenuHeader:
                case MenuItemRole.TopLevelHeader:
                    return this._menuItem;
            }
        }

        KeyTipAlignment IKeyTip.Alignment
        {
            get { return KeyTipAlignment.TopCenter; }
        }

        string IKeyTip.AutoGeneratePrefix
        {
            get
            {
                return null;
            }
        }

        string IKeyTip.Caption
        {
            get
            {
                return this._menuItem.Header.ToString();
            }
        }

        KeyTipActivationBehavior IKeyTip.ActivationBehavior
        {
            get { return KeyTipActivationBehavior.DismissKeyTipsAndDeactivateContainers; }
        }

        bool IKeyTip.IsEnabled
        {
            get
            {
                return true;
            }
        }

        bool IKeyTip.IsVisible
        {
            get
            {
                return true;
            }
        }

        string IKeyTip.KeyTipValue
        {
            get
            {
                return "";
            }
        }

        Point IKeyTip.Location
        {
            get
            {
                return new Point(110, 0);
            }
        }

        char IKeyTip.Mnemonic
        {
            get
            {
                return '\0';
            }
        }

        System.Windows.UIElement IKeyTip.AdornedElement
        {
            get { return _menuItem; }
        }

        char IKeyTip.DefaultPrefix
        {
            get { return '\0'; }
        }

        bool IKeyTip.CanAutoGenerateKeyTip
        {
            get { return true; }
        }

    } 

}
